@@ -79,6 +79,22 @@ pub struct CustomThemeConfig {
     pub blockquote_fg: Option<ColorValue>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub code_fence: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub title_bar_fg: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub scrollbar_fg: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub selection_indicator_fg: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub selection_indicator_bg: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub link_fg: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub link_selected_bg: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub link_selected_fg: Option<ColorValue>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub table_border: Option<ColorValue>,
 }
 
 /// Color value that can be specified in multiple formats
@@ -122,7 +138,6 @@ impl ColorValue {
     }
 }
 
-
 impl Default for UiConfig {
     fn default() -> Self {
         Self {
