@@ -118,6 +118,9 @@ impl InteractiveState {
     }
 
     /// Build element index from parsed blocks
+    ///
+    /// WikiLinks are preprocessed into standard markdown links with `wikilink:` URL prefix,
+    /// so they are detected during Block parsing along with regular links.
     pub fn index_elements(&mut self, blocks: &[Block]) {
         self.elements.clear();
         let mut current_line = 0;
@@ -161,16 +164,28 @@ impl InteractiveState {
                     current_line += lines;
                 }
                 Block::Paragraph { inline, .. } => {
-                    // Extract links from inline elements
-                    for inline_elem in inline {
+                    // Extract links from inline elements (track index for selection highlighting)
+                    for (inline_idx, inline_elem) in inline.iter().enumerate() {
                         if let InlineElement::Link { text, url, .. } = inline_elem {
                             let id = ElementId {
                                 block_idx,
-                                sub_idx: None,
+                                sub_idx: Some(inline_idx),
                             };
 
                             // Parse link target
-                            let target = if let Some(anchor) = url.strip_prefix('#') {
+                            let target = if let Some(wikilink_target) =
+                                url.strip_prefix("wikilink:")
+                            {
+                                // Wikilink parsed from [[target]] or [[target|alias]] syntax
+                                LinkTarget::WikiLink {
+                                    target: wikilink_target.to_string(),
+                                    alias: if text != wikilink_target {
+                                        Some(text.clone())
+                                    } else {
+                                        None
+                                    },
+                                }
+                            } else if let Some(anchor) = url.strip_prefix('#') {
                                 LinkTarget::Anchor(anchor.to_string())
                             } else if url.starts_with("http://") || url.starts_with("https://") {
                                 LinkTarget::External(url.clone())
@@ -199,8 +214,10 @@ impl InteractiveState {
                     current_line += 1;
                 }
                 Block::List { items, .. } => {
-                    // Extract checkboxes
+                    // Extract checkboxes and links from list items
                     for (item_idx, item) in items.iter().enumerate() {
+                        let item_start_line = current_line;
+
                         if let Some(checked) = item.checked {
                             let id = ElementId {
                                 block_idx,
@@ -218,6 +235,58 @@ impl InteractiveState {
                                 line_range: (current_line, current_line + 1),
                             });
                         }
+
+                        // Also extract links from list items (e.g., TOC links)
+                        for (inline_idx, inline_elem) in item.inline.iter().enumerate() {
+                            if let InlineElement::Link { text, url, .. } = inline_elem {
+                                // Use a composite sub_idx to differentiate from checkboxes
+                                // Format: item_idx * 1000 + inline_idx + 100 (to avoid collision with checkbox indices)
+                                let id = ElementId {
+                                    block_idx,
+                                    sub_idx: Some(item_idx * 1000 + inline_idx + 100),
+                                };
+
+                                // Parse link target
+                                let target = if let Some(wikilink_target) =
+                                    url.strip_prefix("wikilink:")
+                                {
+                                    // Wikilink parsed from [[target]] or [[target|alias]] syntax
+                                    LinkTarget::WikiLink {
+                                        target: wikilink_target.to_string(),
+                                        alias: if text != wikilink_target {
+                                            Some(text.clone())
+                                        } else {
+                                            None
+                                        },
+                                    }
+                                } else if let Some(anchor) = url.strip_prefix('#') {
+                                    LinkTarget::Anchor(anchor.to_string())
+                                } else if url.starts_with("http://") || url.starts_with("https://")
+                                {
+                                    LinkTarget::External(url.clone())
+                                } else if let Some((path, anchor)) = url.split_once('#') {
+                                    LinkTarget::RelativeFile {
+                                        path: path.into(),
+                                        anchor: Some(anchor.to_string()),
+                                    }
+                                } else {
+                                    LinkTarget::RelativeFile {
+                                        path: url.into(),
+                                        anchor: None,
+                                    }
+                                };
+
+                                self.elements.push(InteractiveElement {
+                                    id,
+                                    element_type: ElementType::Link {
+                                        link: Link::new(text.clone(), target, 0),
+                                        line_idx: item_start_line,
+                                    },
+                                    line_range: (item_start_line, item_start_line + 1),
+                                });
+                            }
+                        }
+
                         current_line += 1;
                     }
                 }
@@ -294,8 +363,14 @@ impl InteractiveState {
                     current_line += count_single_block_lines(block);
                 }
             }
+
+            // Account for blank line added after each block in render_markdown_enhanced
+            current_line += 1;
         }
 
+        // Sort elements by line position for proper navigation order
+        self.elements.sort_by_key(|e| e.line_range.0);
+
         // Reset selection if elements changed
         if self.current_index.is_some() {
             if self.elements.is_empty() {
@@ -412,7 +487,7 @@ impl InteractiveState {
         } else if self.elements.is_empty() {
             "[INTERACTIVE] No interactive elements in this section | Esc:Exit".to_string()
         } else {
-            "[INTERACTIVE] Tab:Next Shift+Tab:Previous Esc:Exit".to_string()
+            "[INTERACTIVE] Tab:Next Shift+Tab:Prev u/d:Page Esc:Exit".to_string()
         }
     }
 
@@ -423,6 +498,39 @@ impl InteractiveState {
         }
     }
 
+    /// Enter interactive mode at the element closest to the given scroll position
+    /// This preserves the user's current view instead of jumping to the first element
+    pub fn enter_at_scroll_position(&mut self, scroll_pos: usize) {
+        if self.elements.is_empty() {
+            self.current_index = None;
+            return;
+        }
+
+        // Find the element whose start line is closest to the scroll position
+        // Prefer elements that are at or just after the scroll position
+        let mut best_idx = 0;
+        let mut best_distance = usize::MAX;
+
+        for (idx, element) in self.elements.iter().enumerate() {
+            let (start_line, _) = element.line_range;
+
+            // Calculate distance, preferring elements at or after scroll position
+            let distance = if start_line >= scroll_pos {
+                start_line - scroll_pos
+            } else {
+                // Element is above scroll position - add penalty to prefer visible elements
+                (scroll_pos - start_line) + 1000
+            };
+
+            if distance < best_distance {
+                best_distance = distance;
+                best_idx = idx;
+            }
+        }
+
+        self.current_index = Some(best_idx);
+    }
+
     /// Exit interactive mode
     pub fn exit(&mut self) {
         self.current_index = None;
@@ -623,6 +731,7 @@ fn count_block_lines(blocks: &[Block]) -> usize {
 /// Count lines for a single block
 fn count_single_block_lines(block: &Block) -> usize {
     match block {
+        Block::Heading { .. } => 1,
         Block::Paragraph { .. } => 1,
         Block::Code { content, .. } => 2 + content.lines().count(),
         Block::List { items, .. } => items.len(),
