@@ -1,8 +1,10 @@
 mod app;
+mod help_text;
 mod interactive;
 mod syntax;
 pub mod terminal_compat;
 pub mod theme;
+pub mod tty; // Public module for TTY handling
 mod ui;
 
 pub use app::App;
@@ -12,12 +14,13 @@ pub use theme::ThemeName;
 
 use color_eyre::Result;
 use crossterm::ExecutableCommand;
-use crossterm::event::{self, Event, KeyCode, KeyEventKind, KeyModifiers};
+use crossterm::event::{Event, KeyCode, KeyEventKind};
 use crossterm::terminal::{
     EnterAlternateScreen, LeaveAlternateScreen, disable_raw_mode, enable_raw_mode,
 };
 use ratatui::DefaultTerminal;
 use std::io::stdout;
+use std::time::Duration;
 
 /// Suspend the TUI, run an external editor, then restore the TUI
 fn run_editor(terminal: &mut DefaultTerminal, file_path: &std::path::PathBuf) -> Result<()> {
@@ -56,7 +59,31 @@ pub fn run(terminal: &mut DefaultTerminal, app: App) -> Result<()> {
     loop {
         terminal.draw(|frame| ui::render(frame, &mut app))?;
 
-        if let Event::Key(key) = event::read()? {
+        // Handle pending editor file open (from link following non-markdown files)
+        if let Some(file_path) = app.pending_editor_file.take() {
+            let filename = file_path
+                .file_name()
+                .and_then(|n| n.to_str())
+                .unwrap_or("file");
+            match run_editor(terminal, &file_path) {
+                Ok(_) => {
+                    app.status_message = Some(format!("✓ Opened {} in editor", filename));
+                }
+                Err(e) => {
+                    app.status_message = Some(format!("✗ Failed to open {}: {}", filename, e));
+                }
+            }
+            continue; // Redraw after returning from editor
+        }
+
+        // Poll for events with timeout to allow status message expiration
+        // Use 100ms timeout for responsive UI updates
+        if !tty::poll_event(Duration::from_millis(100))? {
+            // No event, just continue loop to redraw (handles status message timeout)
+            continue;
+        }
+
+        if let Event::Key(key) = tty::read_event()? {
             if key.kind == KeyEventKind::Press {
                 // Handle help mode scrolling
                 if app.show_help {
@@ -85,6 +112,20 @@ pub fn run(terminal: &mut DefaultTerminal, app: App) -> Result<()> {
                         _ => {}
                     }
                 }
+                // Handle file creation confirmation
+                else if app.mode == app::AppMode::ConfirmFileCreate {
+                    match key.code {
+                        KeyCode::Char('y') | KeyCode::Char('Y') | KeyCode::Enter => {
+                            if let Err(e) = app.confirm_file_create() {
+                                app.status_message = Some(format!("✗ Error: {}", e));
+                            }
+                        }
+                        KeyCode::Char('n') | KeyCode::Char('N') | KeyCode::Esc => {
+                            app.cancel_file_create();
+                        }
+                        _ => {}
+                    }
+                }
                 // Handle interactive mode
                 else if app.mode == app::AppMode::Interactive {
                     // Check if we're in table navigation mode
@@ -238,13 +279,16 @@ pub fn run(terminal: &mut DefaultTerminal, app: App) -> Result<()> {
                         }
 
                         match key.code {
-                            KeyCode::Esc => app.exit_interactive_mode(),
+                            KeyCode::Esc | KeyCode::Char('i') => app.exit_interactive_mode(),
                             KeyCode::Tab => {
-                                if key.modifiers.contains(KeyModifiers::SHIFT) {
-                                    app.interactive_state.previous();
-                                } else {
-                                    app.interactive_state.next();
-                                }
+                                app.interactive_state.next();
+                                // Auto-scroll to keep element in view
+                                app.scroll_to_interactive_element(20);
+                                // Update status bar
+                                app.status_message = Some(app.interactive_state.status_text());
+                            }
+                            KeyCode::BackTab => {
+                                app.interactive_state.previous();
                                 // Auto-scroll to keep element in view
                                 app.scroll_to_interactive_element(20);
                                 // Update status bar
@@ -276,6 +320,13 @@ pub fn run(terminal: &mut DefaultTerminal, app: App) -> Result<()> {
                                     app.status_message = Some(format!("✗ Error: {}", e));
                                 }
                             }
+                            // Page motions in interactive mode
+                            KeyCode::Char('d') | KeyCode::PageDown => {
+                                app.scroll_page_down_interactive();
+                            }
+                            KeyCode::Char('u') | KeyCode::PageUp => {
+                                app.scroll_page_up_interactive();
+                            }
                             KeyCode::Char('q') => return Ok(()),
                             _ => {}
                         }
@@ -314,40 +365,81 @@ pub fn run(terminal: &mut DefaultTerminal, app: App) -> Result<()> {
                     // Clear status message on any key press in link mode
                     app.status_message = None;
 
-                    match key.code {
-                        KeyCode::Esc => app.exit_link_follow_mode(),
-                        KeyCode::Enter => {
-                            if let Err(e) = app.follow_selected_link() {
-                                // Show error in status message
-                                app.status_message = Some(format!("✗ Error: {}", e));
+                    // Handle search input mode
+                    if app.link_search_active {
+                        match key.code {
+                            KeyCode::Esc => {
+                                // Stop search but keep filter
+                                app.stop_link_search();
                             }
-                            app.update_content_metrics();
+                            KeyCode::Enter => {
+                                // Stop search and follow selected link
+                                app.stop_link_search();
+                                if let Err(e) = app.follow_selected_link() {
+                                    app.status_message = Some(format!("✗ Error: {}", e));
+                                }
+                                app.update_content_metrics();
+                            }
+                            KeyCode::Backspace => {
+                                app.link_search_pop();
+                            }
+                            KeyCode::Char(c) => {
+                                app.link_search_push(c);
+                            }
+                            KeyCode::Down => app.next_link(),
+                            KeyCode::Up => app.previous_link(),
+                            _ => {}
                         }
-                        KeyCode::Tab => {
-                            if key.modifiers.contains(KeyModifiers::SHIFT) {
-                                app.previous_link();
-                            } else {
+                    } else {
+                        // Normal link follow mode
+                        match key.code {
+                            KeyCode::Esc => {
+                                if !app.link_search_query.is_empty() {
+                                    // First Esc clears the search
+                                    app.clear_link_search();
+                                } else {
+                                    app.exit_link_follow_mode();
+                                }
+                            }
+                            KeyCode::Enter => {
+                                if let Err(e) = app.follow_selected_link() {
+                                    // Show error in status message
+                                    app.status_message = Some(format!("✗ Error: {}", e));
+                                }
+                                app.update_content_metrics();
+                            }
+                            KeyCode::Tab => {
                                 app.next_link();
                             }
-                        }
-                        KeyCode::Char('j') | KeyCode::Down => app.next_link(),
-                        KeyCode::Char('k') | KeyCode::Up => app.previous_link(),
-                        KeyCode::Char(c @ '1'..='9') => {
-                            // Direct link selection by number
-                            let idx = c.to_digit(10).unwrap() as usize - 1;
-                            if idx < app.links_in_view.len() {
-                                app.selected_link_idx = Some(idx);
+                            KeyCode::BackTab => {
+                                app.previous_link();
                             }
+                            KeyCode::Char('/') => {
+                                // Start search mode
+                                app.start_link_search();
+                            }
+                            KeyCode::Char('j') | KeyCode::Down => app.next_link(),
+                            KeyCode::Char('k') | KeyCode::Up => app.previous_link(),
+                            KeyCode::Char(c @ '1'..='9') => {
+                                // Direct link selection by number (searches original indices)
+                                let idx = c.to_digit(10).unwrap() as usize - 1;
+                                // Find this index in the filtered list
+                                if let Some(display_idx) =
+                                    app.filtered_link_indices.iter().position(|&i| i == idx)
+                                {
+                                    app.selected_link_idx = Some(display_idx);
+                                }
+                            }
+                            KeyCode::Char('p') => {
+                                // Jump to parent heading while staying in link mode
+                                app.jump_to_parent_links();
+                            }
+                            // Copy operations work in link mode too
+                            KeyCode::Char('y') => app.copy_content(),
+                            KeyCode::Char('Y') => app.copy_anchor(),
+                            KeyCode::Char('q') => return Ok(()),
+                            _ => {}
                         }
-                        KeyCode::Char('p') => {
-                            // Jump to parent heading while staying in link mode
-                            app.jump_to_parent_links();
-                        }
-                        // Copy operations work in link mode too
-                        KeyCode::Char('y') => app.copy_content(),
-                        KeyCode::Char('Y') => app.copy_anchor(),
-                        KeyCode::Char('q') => return Ok(()),
-                        _ => {}
                     }
                 }
                 // Handle search mode separately
@@ -425,6 +517,8 @@ pub fn run(terminal: &mut DefaultTerminal, app: App) -> Result<()> {
                         }
                         // Interactive element navigation
                         KeyCode::Char('i') => app.enter_interactive_mode(),
+                        // Raw source toggle
+                        KeyCode::Char('r') => app.toggle_raw_source(),
                         // Link following
                         KeyCode::Char('f') => app.enter_link_follow_mode(),
                         KeyCode::Char('b') | KeyCode::Backspace => {
